@@ -5,7 +5,6 @@ from urllib.parse import urlparse
 import click
 from pycognito import Cognito
 
-from .auth import login
 from .vars import COGNITO_NETLOC_MAPPING, CREDSTORE_PATH, DEFAULT_PROFILE
 
 
@@ -28,20 +27,22 @@ class URL(click.ParamType):
         return parsed.netloc
 
 
-@click.command(help="Stores login credentials for use by the Nom Nom Data CLI")
+@click.command(
+    name="login", help="Stores login credentials for use by the Nom Nom Data CLI",
+)
 @click.option(
     "--profile", envvar="NND_PROFILE", default=DEFAULT_PROFILE, show_default=True
 )
 @click.option(
     "--nomitall-url",
     envvar="NND_NOMITALL_URL",
-    default="https://user.api.nomitall.com",
+    default="https://user.api.nomnomdata.com",
     show_default=True,
     type=URL(),
 )
-def login(profile, nomitall_url):
-    username = click.prompt("Please enter your nomnomdata.com username")
-    password = click.prompt("Please enter your nomnomdata.com password", hide_input=True)
+@click.option("--username", prompt="NND Username")
+@click.option("--password", prompt=True, hide_input=True)
+def login(profile, nomitall_url, username, password):
     if not CREDSTORE_PATH.exists():
         CREDSTORE_PATH.parent.mkdir(parents=True, exist_ok=True)
         creds = defaultdict(dict)
